@@ -120,14 +120,23 @@ sub check_variable_declarations {
                     # warn "look: ", Data::Dumper::Dumper(\@Perlito5::SCOPE_STMT);
                     my $sigil = $var->{_real_sigil} || $var->{sigil};
                     if ($sigil ne '*' && $sigil ne '&') {
-                        die 'Global symbol "' . $sigil . $var->{name} . '"'
-                            . ' requires explicit package name'
-                            . ' at ' . $Perlito5::FILE_NAME;
+                        Perlito5::Compiler::error 'Global symbol "' . $sigil . $var->{name} . '"'
+                            . ' requires explicit package name';
                     }
                 }
                 $var->{_decl} = 'global';
                 $var->{_namespace} = $Perlito5::PKG_NAME;
             }
+
+            if ($ENV{PERLITO5DEV}) {
+                my $compiletime_name =
+                      ($var->{_real_sigil} || $var->{sigil})
+                    . ($var->{namespace} || $var->{_namespace} || "C_")
+                    . "::" . $var->{name}
+                    . ($var->{_decl} eq "global" ? "" : "_" . $var->{_id});
+                $Perlito5::GLOBAL->{$compiletime_name} = { value => undef, ast => $var };
+            }
+
         }
     }
     push @{ $Perlito5::SCOPE->{block} }, @Perlito5::SCOPE_STMT;
@@ -153,75 +162,5 @@ sub get_snapshot {
     return { block => \@result };
 }
 
-sub _dump_global {
-    my ($item, $seen, $dumper_seen, $vars, $tab) = @_;
-    my $n = $item->{sigil} . $item->{namespace} . "::" . $item->{name};
-    if (!$seen->{$n}) {
-        if ($item->{sigil} eq '$') {
-            push @$vars, $tab . "$n = " . Perlito5::Dumper::_dumper( eval $n, "  ", $dumper_seen, $n ) . ";\n";
-        }
-        elsif ($item->{sigil} eq '@' || $item->{sigil} eq '%') {
-            my $ref = "\\$n";
-            my $d = Perlito5::Dumper::_dumper( eval $ref, $tab . "  ", $dumper_seen, $ref );
-            if ($d eq '[]' || $d eq '{}') {
-                push @$vars, $tab . "$n = ();\n"
-            }
-            else {
-                push @$vars, $tab . "$n = " . $item->{sigil} . "{" . $d . "};\n";
-            }
-        }
-        elsif ($item->{sigil} eq '*') {
-            # TODO - look for aliasing
-            #   *v1 = \$v2
-            push @$vars, $tab . "# $n\n";
-            for (qw/ $ @ % /) {
-                local $item->{sigil} = $_;
-                _dump_global($item, $seen, $dumper_seen, $vars, $tab);
-            }
-        }
-        $seen->{$n} = 1;
-    }
-}
-
-sub _emit_globals {
-    my ($scope, $seen, $dumper_seen, $vars, $tab) = @_;
-    my $block = $scope->{block};
-    for my $item (@$block) {
-        if (ref($item) eq 'Perlito5::AST::Var' && !$item->{_decl}) {
-            $item->{_decl} = 'global';
-        }
-        if (ref($item) eq 'Perlito5::AST::Var' && $item->{_decl} eq 'global') {
-            $item->{namespace} ||= $item->{_namespace};
-            next if $item->{name} eq '0' || $item->{name} > 0;  # skip regex and $0
-            _dump_global($item, $seen, $dumper_seen, $vars, $tab);
-        }
-        if (ref($item) eq 'Perlito5::AST::Var' && $item->{_decl} eq 'my') {
-            my $id = $item->{_id};
-            if (!$seen->{$id}) {
-                push @$vars, $tab . "# my " . $item->{sigil} . $item->{name} . ";\n";
-            }
-            $seen->{$id} = 1;
-        }
-        if ( ref($item) eq 'HASH' && $item->{block} ) {
-            # lookup in the inner scope
-            push @$vars, $tab . "{\n";
-            _emit_globals($item, $seen, $dumper_seen, $vars, $tab . "  ");
-            push @$vars, $tab . "}\n";
-        }
-    }
-}
-
-sub emit_globals {
-    # return a structure with the global variable declarations
-    # this is used to initialize the ahead-of-time program
-    my $scope = shift() // $Perlito5::BASE_SCOPE;
-    my @vars;
-    my %seen;
-    my $dumper_seen = {};
-    my $tab = "";
-    _emit_globals($scope, \%seen, $dumper_seen, \@vars, $tab);
-    return join("", @vars);
-}
-
 1;
 
